@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """python library for accessing the openHAB REST API."""
 
 #
@@ -19,20 +18,17 @@
 #
 
 # pylint: disable=bad-indentation
-import json
 import logging
-import pathlib
-import time
 import typing
-import warnings
 
-import requests
-from requests.auth import HTTPBasicAuth
-from requests_oauthlib import OAuth2Session
+import authlib.integrations.httpx_client
+import httpx
 
 import openhab.items
 import openhab.rules
 
+from .config import Oauth2Config, Oauth2Token
+
 __author__ = 'Georges Toth <georges@trypill.org>'
 __license__ = 'AGPLv3+'
 
@@ -43,9 +39,9 @@ class OpenHAB:
   def __init__(self, base_url: str,
                username: typing.Optional[str] = None,
                password: typing.Optional[str] = None,
-               http_auth: typing.Optional[requests.auth.AuthBase] = None,
+               http_auth: typing.Optional[httpx.Auth] = None,
                timeout: typing.Optional[float] = None,
-               oauth2_config: typing.Optional[typing.Dict[str, typing.Any]] = None
+               oauth2_config: typing.Optional[typing.Dict[str, typing.Any]] = None,
                ) -> None:
     """Class constructor.
 
@@ -74,8 +70,8 @@ class OpenHAB:
                       provided password, in case openHAB requires authentication.
       password (str, optional): A optional password, used in conjunction with a optional
                       provided username, in case openHAB requires authentication.
-      http_auth (AuthBase, optional): An alternative to username/password pair, is to
-                            specify a custom http authentication object of type :class:`requests.auth.AuthBase`.
+      http_auth (Auth, optional): An alternative to username/password pair, is to
+                            specify a custom http authentication object of type :class:`requests.Auth`.
       timeout (float, optional): An optional timeout for REST transactions
       oauth2_config: Optional OAuth2 configuration dictionary
 
@@ -85,36 +81,30 @@ class OpenHAB:
     self.url_rest = base_url
     self.url_base = base_url.rsplit('/', 1)[0]
 
-    self.oauth2_config = oauth2_config
+    self.oauth2_config: typing.Optional[Oauth2Config] = None
 
-    if self.oauth2_config is not None:
-      self._validate_oauth2_config(self.oauth2_config)
+    if oauth2_config is not None:
+      self.oauth2_config = Oauth2Config(**oauth2_config)
 
-      if 'expires_at' not in self.oauth2_config['token']:
-        self.oauth2_config['token']['expires_at'] = time.time() - 10
+      self.session = authlib.integrations.httpx_client.OAuth2Client(client_id=self.oauth2_config.client_id,
+                                                                    token=self.oauth2_config.token.model_dump(),
+                                                                    update_token=self._oauth2_token_updater,
+                                                                    )
 
-      self.session = OAuth2Session(self.oauth2_config['client_id'],
-                                   token=self.oauth2_config['token'],
-                                   auto_refresh_url=f'{self.url_rest}/auth/token',
-                                   auto_refresh_kwargs={'client_id': self.oauth2_config['client_id']},
-                                   token_updater=self._oauth2_token_updater
-                                   )
+      print('>>>>', self.oauth2_config.token.refresh_token)
 
-      token_cache_path = pathlib.Path(self.oauth2_config['token_cache'])
-      if not token_cache_path.is_file():
-        self._oauth2_token_updater(self.oauth2_config['token'])
+      self.session.metadata['token_endpoint'] = f'{self.url_rest}/auth/token'
+
+      if not self.oauth2_config.token_cache.is_file():
+        self._oauth2_token_updater(self.oauth2_config.token.model_dump())
 
     else:
-      self.session = requests.Session()
+      self.session = httpx.Client(timeout=timeout)
 
       if http_auth is not None:
         self.session.auth = http_auth
       elif not (username is None or password is None):
-        self.session.auth = HTTPBasicAuth(username, password)
-
-    self.session.headers['accept'] = 'application/json'
-
-    self.timeout = timeout
+        self.session.auth = httpx.BasicAuth(username, password)
 
     self.logger = logging.getLogger(__name__)
 
@@ -129,14 +119,14 @@ class OpenHAB:
     return self._rules
 
   @staticmethod
-  def _check_req_return(req: requests.Response) -> None:
+  def _check_req_return(req: httpx.Response) -> None:
     """Internal method for checking the return value of a REST HTTP request.
 
     Args:
       req (requests.Response): A requests Response object.
 
     Returns:
-      None: Returns None if no error occured; else raises an exception.
+      None: Returns None if no error occurred; else raises an exception.
 
     Raises:
       ValueError: Raises a ValueError exception in case of a non-successful
@@ -157,13 +147,14 @@ class OpenHAB:
     Returns:
       dict: Returns a dict containing the data returned by the OpenHAB REST server.
     """
-    r = self.session.get(self.url_rest + uri_path, timeout=self.timeout)
+    r = self.session.get(self.url_rest + uri_path)
     self._check_req_return(r)
     return r.json()
 
   def req_post(self,
                uri_path: str,
-               data: typing.Optional[typing.Union[str, bytes, typing.Mapping[str, typing.Any], typing.Iterable[typing.Tuple[str, typing.Optional[str]]]]] = None
+               data: typing.Optional[typing.Union[str, bytes, typing.Mapping[str, typing.Any], typing.Iterable[
+                 typing.Tuple[str, typing.Optional[str]]]]] = None,
                ) -> None:
     """Helper method for initiating a HTTP POST request.
 
@@ -177,14 +168,17 @@ class OpenHAB:
     Returns:
       None: No data is returned.
     """
-    r = self.session.post(self.url_rest + uri_path, data=data, headers={'Content-Type': 'text/plain'}, timeout=self.timeout)
+    headers = self.session.headers
+    headers['Content-Type'] = 'text/plain'
+
+    r = self.session.post(self.url_rest + uri_path, content=data, headers=headers)
     self._check_req_return(r)
 
   def req_put(self,
               uri_path: str,
               data: typing.Optional[dict] = None,
               json_data: typing.Optional[dict] = None,
-              headers: typing.Optional[dict] = None
+              headers: typing.Optional[dict] = None,
               ) -> None:
     """Helper method for initiating a HTTP PUT request.
 
@@ -202,8 +196,12 @@ class OpenHAB:
     """
     if headers is None:
       headers = {'Content-Type': 'text/plain'}
+      content = data
+      data = None
+    else:
+      content = None
 
-    r = self.session.put(self.url_rest + uri_path, data=data, json=json_data, headers=headers, timeout=self.timeout)
+    r = self.session.put(self.url_rest + uri_path, content=content, data=data, json=json_data, headers=headers)
     self._check_req_return(r)
 
   # fetch all items
@@ -217,7 +215,7 @@ class OpenHAB:
     res = self.req_get('/items/')
 
     for i in res:
-      if not i['name'] in items:
+      if i['name'] not in items:
         items[i['name']] = self.json_to_item(i)
 
     return items
@@ -250,7 +248,7 @@ class OpenHAB:
     _type = json_data['type']
 
     if _type == 'Group' and 'groupType' in json_data:
-      _type = json_data["groupType"]
+      _type = json_data['groupType']
 
     if _type == 'Group' and 'groupType' not in json_data:
       return openhab.items.GroupItem(self, json_data)
@@ -301,11 +299,11 @@ class OpenHAB:
     Returns:
       True or False depending on if the logout did succeed.
     """
-    if self.oauth2_config is None or not isinstance(self.session, OAuth2Session):
+    if self.oauth2_config is None or not isinstance(self.session, authlib.integrations.httpx_client.OAuth2Client):
       raise ValueError('You are trying to logout from a non-OAuth2 session. This is not supported!')
 
-    data = {'refresh_token': self.oauth2_config['token']['refresh_token'],
-            'id': self.oauth2_config['client_id']
+    data = {'refresh_token': self.oauth2_config.token.refresh_token,
+            'id': self.oauth2_config.client_id,
             }
     url_logout = f'{self.url_rest}/auth/logout'
 
@@ -313,31 +311,18 @@ class OpenHAB:
 
     return res.status_code == 200
 
-  @staticmethod
-  def _validate_oauth2_config(oauth2_config: typing.Dict[str, typing.Any]) -> bool:
-    """Validate OAuth2 configuration."""
-    if not ('client_id' in oauth2_config and 'token_cache' in oauth2_config and 'token' in oauth2_config):
-      return False
-
-    # pylint: disable=too-many-boolean-expressions
-    if 'access_token' not in oauth2_config['token'] or \
-      'expires_in' not in oauth2_config['token'] or \
-      'refresh_token' not in oauth2_config['token'] or \
-      'scope' not in oauth2_config['token'] or \
-      'token_type' not in oauth2_config['token'] or \
-      'user' not in oauth2_config['token'] or \
-      'name' not in oauth2_config['token']['user'] or \
-      'roles' not in oauth2_config['token']['user']:
-      return False
-
-    return True
-
-  def _oauth2_token_updater(self, token: typing.Dict[str, typing.Any]) -> None:
+  def _oauth2_token_updater(self, token: typing.Dict[str, typing.Any],
+                            refresh_token: typing.Any = None,
+                            access_token: typing.Any = None) -> None:
     if self.oauth2_config is None:
       raise ValueError('OAuth2 configuration is not set; invalid action!')
 
-    with open(self.oauth2_config['token_cache'], 'w', encoding='utf-8') as fhdl:
-      json.dump(token, fhdl)
+    self.oauth2_config.token = Oauth2Token(**token)
+
+    print('>SSS>>>', self.oauth2_config.token.refresh_token)
+
+    with self.oauth2_config.token_cache.open('w', encoding='utf-8') as fhdl:
+      fhdl.write(self.oauth2_config.token.model_dump_json())
 
   def create_or_update_item(self,
                             name: str,
@@ -349,7 +334,7 @@ class OpenHAB:
                             group_names: typing.Optional[typing.List[str]] = None,
                             group_type: typing.Optional[typing.Union[str, typing.Type[openhab.items.Item]]] = None,
                             function_name: typing.Optional[str] = None,
-                            function_params: typing.Optional[typing.List[str]] = None
+                            function_params: typing.Optional[typing.List[str]] = None,
                             ) -> None:
     """Creates a new item in openHAB if there is no item with name 'name' yet.
 
@@ -371,13 +356,15 @@ class OpenHAB:
                      Can be one of ['EQUALITY', 'AND', 'OR', 'NAND', 'NOR', 'AVG', 'SUM', 'MAX', 'MIN', 'COUNT', 'LATEST', 'EARLIEST']
       function_params: Optional list of function params (no documentation found), depending on function name.
     """
-    paramdict: typing.Dict[str, typing.Union[str, typing.List[str], typing.Dict[str, typing.Union[str, typing.List[str]]]]] = {}
+    paramdict: typing.Dict[
+      str, typing.Union[str, typing.List[str], typing.Dict[str, typing.Union[str, typing.List[str]]]]] = {}
 
     if isinstance(_type, type):
       if issubclass(_type, openhab.items.Item):
         itemtypename = _type.TYPENAME
       else:
-        raise ValueError(f'_type parameter must be a valid subclass of type *Item* or a string name of such a class; given value is "{str(_type)}"')
+        raise ValueError(
+          f'_type parameter must be a valid subclass of type *Item* or a string name of such a class; given value is "{str(_type)}"')
     else:
       itemtypename = _type
 
@@ -406,12 +393,14 @@ class OpenHAB:
           paramdict['groupType'] = group_type.TYPENAME
           # paramdict['function'] = {'name': 'AVG'}
         else:
-          raise ValueError(f'group_type parameter must be a valid subclass of type *Item* or a string name of such a class; given value is "{str(group_type)}"')
+          raise ValueError(
+            f'group_type parameter must be a valid subclass of type *Item* or a string name of such a class; given value is "{str(group_type)}"')
       else:
         paramdict['groupType'] = group_type
 
     if function_name is not None:
-      if function_name not in ('EQUALITY', 'AND', 'OR', 'NAND', 'NOR', 'AVG', 'SUM', 'MAX', 'MIN', 'COUNT', 'LATEST', 'EARLIEST'):
+      if function_name not in (
+          'EQUALITY', 'AND', 'OR', 'NAND', 'NOR', 'AVG', 'SUM', 'MAX', 'MIN', 'COUNT', 'LATEST', 'EARLIEST'):
         raise ValueError(f'Invalid function name "{function_name}')
 
       if function_name in ('AND', 'OR', 'NAND', 'NOR') and (not function_params or len(function_params) != 2):
@@ -428,14 +417,3 @@ class OpenHAB:
     self.logger.debug('About to create item with PUT request:\n%s', str(paramdict))
 
     self.req_put(f'/items/{name}', json_data=paramdict, headers={'Content-Type': 'application/json'})
-
-
-# noinspection PyPep8Naming
-class openHAB(OpenHAB):
-  """Legacy class wrapper, **do not** use."""
-
-  def __init__(self, *args: typing.Any, **kwargs: typing.Any) -> None:
-    """Constructor."""
-    super().__init__(*args, **kwargs)
-
-    warnings.warn('The use of the "openHAB" class is deprecated, please use "OpenHAB" instead.', DeprecationWarning)
