@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """python library for accessing the openHAB REST API."""
 
 #
@@ -162,7 +161,7 @@ class Item:
     """Private method for verifying the new value before modifying the state of the item."""
     if self.type_ == 'String':
       if not isinstance(value, (str, bytes)):
-        raise ValueError()
+        raise ValueError
     elif self.types:
       validation = False
 
@@ -177,16 +176,14 @@ class Item:
       if not validation:
         raise ValueError(f'Invalid value "{value}"')
     else:
-      raise ValueError()
+      raise ValueError
 
   def _parse_rest(self, value: str) -> typing.Tuple[str, str]:
     """Parse a REST result into a native object."""
-    # pylint: disable=no-self-use
     return value, ''
 
   def _rest_format(self, value: str) -> typing.Union[str, bytes]:
     """Format a value before submitting to openHAB."""
-    # pylint: disable=no-self-use
     _value = value  # type: typing.Union[str, bytes]
 
     # Only ascii encoding is supported by default. If non-ascii characters were provided, convert them to bytes.
@@ -563,9 +560,9 @@ class ColorItem(DimmerItem):
 
   TYPENAME = 'Color'
   types = [openhab.command_types.OnOffType, openhab.command_types.PercentType, openhab.command_types.IncreaseDecreaseType, openhab.command_types.ColorType]
-  state_types = [openhab.command_types.ColorType]  # type: ignore
+  state_types = [openhab.command_types.ColorType]
 
-  def _parse_rest(self, value: str) -> typing.Tuple[typing.Optional[typing.Tuple[int, int, float]], str]:  # type: ignore[override]
+  def _parse_rest(self, value: str) -> typing.Tuple[typing.Optional[typing.Tuple[float, float, float]], str]:  # type: ignore[override]
     """Parse a REST result into a native object.
 
     Args:
